SystemOrganization addCategory: #'Versionner-Morphic-Tests'!

!MBPackageInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'dkh 3/6/2011 21:00'!
testMorphicMenu
	| menu |
	menu := MenuMorph new.
	self deny: (menu hasItems).

	package listMenu: menu requestor: nil.
	self assert: (menu hasItems).
! !

!MBBaselineInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'dkh 3/6/2011 20:56'!
testBrowseInfo
	| systemWindow |
	systemWindow := (MBBrowseCommand target: info for: browser) execute.
	self assert: systemWindow notNil.
	systemWindow delete.! !

!MBBaselineInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'dkh 3/6/2011 20:57'!
testInfoListMorphicMenu
	"Check if the info has commands defined"
 	| menu |
	
	menu := MenuMorph new.
	self deny: menu hasItems.
	info listMenu: menu requestor: browser .
	self assert: menu hasItems.
! !

!MBBaselineInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'TesterBob 3/28/2011 15:45'!
testRemoveInfo
	| baselineInfo configurationInfo |
	configuration compile: 'defaultSecond: spec 
        <version: ''default2''>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: ''http://www.squeaksource.com/Zork''.
		    spec package: ''Zork-Core''.
                ].'.

	configurationInfo := MBConfigurationRoot current configurationInfoFor: configuration.
	baselineInfo := configurationInfo baselines detect: [:inf | inf version versionString = 'default2'].
	[ (MBRemoveCommand target: baselineInfo for: browser ) execute ] 
		valueSupplyingAnswer: true.

	self deny: (configuration methodDictionary includesKey: #defaultSecond: ) ! !

MBAbstractTest subclass: #MBPluggableIconListMorphTest
	instanceVariableNames: 'browser window'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Morphic-Tests'!

!MBPluggableIconListMorphTest methodsFor: 'hooks' stamp: 'AlexandreBergel 3/26/2011 22:41'!
listSymbol
	^ #(#a #b #c)! !

!MBPluggableIconListMorphTest methodsFor: 'hooks' stamp: 'AlexandreBergel 3/26/2011 22:42'!
selectionSymbol
	^ 2! !

!MBPluggableIconListMorphTest methodsFor: 'hooks' stamp: 'AlexandreBergel 3/26/2011 22:42'!
selectionSymbol: v
	^ 2! !

!MBPluggableIconListMorphTest methodsFor: 'tests' stamp: 'AlexandreBergel 3/26/2011 22:51'!
testListMorph2
	| listMorph |
	self shouldnt: 
		[listMorph := MBPluggableIconListMorph
			on: self
			list: #listSymbol
			selected: #selectionSymbol
			changeSelected: (#selectionSymbol, ':') asSymbol
			menu: #menuSymbol]
		 raise:  Error.
	
	self assert: (listMorph notNil).
	
	listMorph mouseUp: (MouseButtonEvent new setPosition: 20@30; setType: #mouseOver; yourself) 
	! !

MBAbstractTest subclass: #MetacelloBrowserTest
	instanceVariableNames: 'browser window'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Morphic-Tests'!

!MetacelloBrowserTest methodsFor: 'running' stamp: 'AlexandreBergel 2/15/2011 23:58'!
expectedFailures 

	^ { #testAddBaseline }! !

!MetacelloBrowserTest methodsFor: 'util' stamp: 'AlexandreBergel 3/26/2011 23:02'!
getAllWindows
	^ World submorphs select: #isSystemWindow! !

!MetacelloBrowserTest methodsFor: 'running' stamp: 'AlexandreBergel 5/18/2011 16:30'!
setUp
	super setUp.
	browser := VersionnerBrowser new! !

!MetacelloBrowserTest methodsFor: 'running' stamp: 'AlexandreBergel 2/28/2011 17:50'!
tearDown

	super tearDown.
	window ifNotNil: [ window delete ].

	self removeClassIfExist:#ConfigurationOfFOOBAR! !

!MetacelloBrowserTest methodsFor: 'actions' stamp: 'TesterBob 3/28/2011 15:48'!
testAddBaseline
	| repository cls |
	cls := Object subclass: #ConfigurationOfFOOBAR.
	repository := MCHttpRepository 
						location: 'http://www.squeaksource.com/FOOBAR' 
						user: 'anUsername' 
						password: 'aPassword'.
	browser 
		addBaselineForConfiguration: cls
		repository: repository 
		number: '1.2.3' 
		packages: #('Kernel' 'Zork' 'Collections') 
		configurations: #('ConfigurationOfScriptManager').
		
	self assert: (cls selectors size = 1).
	self assert: (cls >> #baseline123:) getSourceFromFile = 'baseline123: spec 
        <version: ''1.2.3-baseline''>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: ''http://www.squeaksource.com/FOOBAR''.    
                "spec 
                        package: ''Example-Core'';
                        package: ''Example-Tests'' with: [ spec requires: ''Example-Core'' ]"
		spec project: ''MetacelloBrowser'' with: [
				spec
					className: ''ConfigurationOfMetacelloBrowser'';
					version: ''1.0-baseline'';
					file:  ''ConfigurationOfMetacelloBrowser'';
					repository: ''http://www.squeaksource.com/MetacelloBrowser'' ].

			spec package: ''Kernel''.
			spec package: ''MetacelloBrowser-Core''.
			spec package: ''Collections''.
                ].'.
	cls removeFromSystem! !

!MetacelloBrowserTest methodsFor: 'actions' stamp: 'AlexandreBergel 3/5/2011 22:49'!
testAddConfiguration
	self should: [browser addConfiguration] raise: Exception! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'TesterBob 3/28/2011 15:47'!
testBrowserRefresh
	| repository cls list configList infoList baseline |
	
	list := browser configurationList.
	window := browser show.
	self assert: (list noneSatisfy: [ :configInfo | configInfo name = 'ConfigurationOfFOOBAR' ] ).

	"We add a new configuration, the list of configuration must be refreshed"
	MetacelloToolBox configurationNamed: #ConfigurationOfFOOBAR.
	cls := Smalltalk globals at: #ConfigurationOfFOOBAR.

	configList := browser configurationList 
							detect: [ :configInfo | configInfo name = 'ConfigurationOfFOOBAR' ] ifNone: [ nil ].
	self assert: configList notNil.
	
	browser configurationSelection: (browser configurationList indexOf: configList).
	self assert: (browser configurationSelection ==  
					(browser configurationList indexOf: configList)).


	"We add a new baseline, the browser must be refreshed"
	infoList := browser infoList. 
	repository := MCHttpRepository 
						location: 'http://www.squeaksource.com/FOOBAR' 
						user: 'anUsername' 
						password: 'aPassword'.
	
	(MBAddBaselineCommand target: configList for: browser)
		addBaselineForConfiguration: cls
		repository: repository 
		number: '1.2.3' 
		packages: #('Kernel' 'Zork' 'Collections') 
		configurations: #('ConfigurationOfScriptManager').
	
	self assert: (browser infoList size > infoList size).
	baseline := (configList baselines) first.
	
	"We copy a baseline, again, the browser should be updated"
	infoList := browser infoList. 
	[  (MBCopyBaselineCommand target: baseline for: browser ) copyBaselineWithNumber: '1.2.4'] 
		valueSupplyingAnswer: 'this is my comment'.
 	self assert: (browser infoList size > infoList size).

	"We remove the version".
	infoList := browser infoList.
	[  (MBRemoveCommand target: baseline for: browser ) execute] 
		valueSupplyingAnswer: true.
 	self assert: (browser infoList size < infoList size).

 
	cls removeFromSystem.
	! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:01'!
testConfigurationInfos
	self assert: (browser configurationInfos allSatisfy: [:info | info class == MBConfigurationInfo]).
! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:01'!
testConfigurationList
	self assert: (browser configurationList allSatisfy: [:each | each isKindOf: MBConfigurationInfo ])! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'AlexandreBergel 1/16/2011 21:55'!
testConfigurationListMenu
	| menu |
	self assert: browser configurationSelection = 1.
	
	menu := MenuMorph new.
	browser configurationListMenu: menu.
	self assert: menu hasItems  
! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'AlexandreBergel 1/16/2011 21:56'!
testConfigurationSelection2
	| menu |
	self assert: browser configurationSelection = 1.
	browser configurationSelection: 2.
	self assert: browser configurationSelection = 2.
	browser configurationSelection: 4.
	self assert: browser configurationSelection = 4.
! !

!MetacelloBrowserTest methodsFor: 'tests' stamp: 'dkh 2/27/2011 13:17'!
testConfigurations
	self assert: (browser configurationClasses allSatisfy: #isBehavior).
! !

!MetacelloBrowserTest methodsFor: 'morphic' stamp: 'AlexandreBergel 5/18/2011 16:30'!
testOpenAndClose
	| windows |
	windows := self getAllWindows.
	VersionnerBrowser open close.
	self assert: (self getAllWindows = windows)! !

!MetacelloBrowserTest methodsFor: 'morphic' stamp: 'AlexandreBergel 3/26/2011 22:58'!
testStep
	browser step! !

MBAbstractTest subclass: #VersionnerTest
	instanceVariableNames: 'browser window'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Morphic-Tests'!

!VersionnerTest methodsFor: 'running' stamp: 'dkh 4/18/2011 20:21'!
expectedFailures 

	true ifTrue: [ ^#() ].
	^ #(testAddBaseline)! !

!VersionnerTest methodsFor: 'util' stamp: 'AlexandreBergel 3/26/2011 23:02'!
getAllWindows
	^ World submorphs select: #isSystemWindow! !

!VersionnerTest methodsFor: 'running' stamp: 'AlexandreBergel 2/16/2011 11:32'!
setUp
	super setUp.
	browser := Versionner new! !

!VersionnerTest methodsFor: 'running' stamp: 'AlexandreBergel 2/28/2011 17:50'!
tearDown

	super tearDown.
	window ifNotNil: [ window delete ].

	self removeClassIfExist:#ConfigurationOfFOOBAR! !

!VersionnerTest methodsFor: 'actions' stamp: 'TesterBob 3/28/2011 15:48'!
testAddBaseline
	| repository cls |
	cls := Object subclass: #ConfigurationOfFOOBAR.
	repository := MCHttpRepository 
						location: 'http://www.squeaksource.com/FOOBAR' 
						user: 'anUsername' 
						password: 'aPassword'.
	browser 
		addBaselineForConfiguration: cls
		repository: repository 
		number: '1.2.3' 
		packages: #('Kernel' 'Zork' 'Collections') 
		configurations: #('ConfigurationOfScriptManager').
		
	self assert: (cls selectors size = 1).
	self assert: (cls >> #baseline123:) getSourceFromFile = 'baseline123: spec 
        <version: ''1.2.3-baseline''>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: ''http://www.squeaksource.com/FOOBAR''.    
                "spec 
                        package: ''Example-Core'';
                        package: ''Example-Tests'' with: [ spec requires: ''Example-Core'' ]"
		spec project: ''Versionner'' with: [
				spec
					className: ''ConfigurationOfVersionner'';
					version: ''1.0-baseline'';
					file:  ''ConfigurationOfVersionner'';
					repository: ''http://www.squeaksource.com/Versionner'' ].

			spec package: ''Kernel''.
			spec package: ''Versionner-Core''.
			spec package: ''Collections''.
                ].'.
	cls removeFromSystem! !

!VersionnerTest methodsFor: 'actions' stamp: 'AlexandreBergel 3/5/2011 22:49'!
testAddConfiguration
	self should: [browser addConfiguration] raise: Exception! !

!VersionnerTest methodsFor: 'tests' stamp: 'TesterBob 3/28/2011 15:47'!
testBrowserRefresh
	| repository cls list configList infoList baseline |
	
	list := browser configurationList.
	window := browser show.
	self assert: (list noneSatisfy: [ :configInfo | configInfo name = 'ConfigurationOfFOOBAR' ] ).

	"We add a new configuration, the list of configuration must be refreshed"
	MetacelloToolBox configurationNamed: #ConfigurationOfFOOBAR.
	cls := Smalltalk globals at: #ConfigurationOfFOOBAR.

	configList := browser configurationList 
							detect: [ :configInfo | configInfo name = 'ConfigurationOfFOOBAR' ] ifNone: [ nil ].
	self assert: configList notNil.
	
	browser configurationSelection: (browser configurationList indexOf: configList).
	self assert: (browser configurationSelection ==  
					(browser configurationList indexOf: configList)).


	"We add a new baseline, the browser must be refreshed"
	infoList := browser infoList. 
	repository := MCHttpRepository 
						location: 'http://www.squeaksource.com/FOOBAR' 
						user: 'anUsername' 
						password: 'aPassword'.
	
	(MBAddBaselineCommand target: configList for: browser)
		addBaselineForConfiguration: cls
		repository: repository 
		number: '1.2.3' 
		packages: #('Kernel' 'Zork' 'Collections') 
		configurations: #('ConfigurationOfScriptManager').
	
	self assert: (browser infoList size > infoList size).
	baseline := (configList baselines) first.
	
	"We copy a baseline, again, the browser should be updated"
	infoList := browser infoList. 
	[  (MBCopyBaselineCommand target: baseline for: browser ) copyBaselineWithNumber: '1.2.4'] 
		valueSupplyingAnswer: 'this is my comment'.
 	self assert: (browser infoList size > infoList size).

	"We remove the version".
	infoList := browser infoList.
	[  (MBRemoveCommand target: baseline for: browser ) execute] 
		valueSupplyingAnswer: true.
 	self assert: (browser infoList size < infoList size).

 
	cls removeFromSystem.
	! !

!VersionnerTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:01'!
testConfigurationInfos
	self assert: (browser configurationInfos allSatisfy: [:info | info class == MBConfigurationInfo]).
! !

!VersionnerTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:01'!
testConfigurationList
	self assert: (browser configurationList allSatisfy: [:each | each isKindOf: MBConfigurationInfo ])! !

!VersionnerTest methodsFor: 'tests' stamp: 'AlexandreBergel 1/16/2011 21:55'!
testConfigurationListMenu
	| menu |
	self assert: browser configurationSelection = 1.
	
	menu := MenuMorph new.
	browser configurationListMenu: menu.
	self assert: menu hasItems  
! !

!VersionnerTest methodsFor: 'tests' stamp: 'AlexandreBergel 1/16/2011 21:56'!
testConfigurationSelection2
	| menu |
	self assert: browser configurationSelection = 1.
	browser configurationSelection: 2.
	self assert: browser configurationSelection = 2.
	browser configurationSelection: 4.
	self assert: browser configurationSelection = 4.
! !

!VersionnerTest methodsFor: 'tests' stamp: 'dkh 2/27/2011 13:17'!
testConfigurations
	self assert: (browser configurationClasses allSatisfy: #isBehavior).
! !

!VersionnerTest methodsFor: 'morphic' stamp: 'AlexandreBergel 3/26/2011 23:02'!
testOpenAndClose
	| windows |
	windows := self getAllWindows.
	Versionner open close.
	self assert: (self getAllWindows = windows)! !

!VersionnerTest methodsFor: 'morphic' stamp: 'AlexandreBergel 3/26/2011 22:58'!
testStep
	browser step! !

!MBInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'AlexandreBergel 3/27/2011 12:05'!
getAllWindows
	^ World submorphs select: #isSystemWindow! !

!MBInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'AlexandreBergel 3/27/2011 12:04'!
testBrowseValidationResult

	| mbInfo windows |
	windows := self getAllWindows.

	MBInfo new browseValidationResults.
	
	mbInfo := MBInfo new.
	mbInfo validate.
	mbInfo browseValidationResults.

	(self getAllWindows copyWithoutAll: windows) do: #delete  ! !

!MBInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'AlexandreBergel 3/27/2011 11:59'!
testCalculateValidationIcon

	| mbInfo |
	MBInfo new calculateValidationIcon.
	
	mbInfo := MBInfo new.
	mbInfo validate.
	mbInfo calculateValidationIcon
	! !

!MBAddBaselineCommandTest methodsFor: '*versionner-morphic-tests' stamp: 'TesterBob 3/28/2011 00:09'!
testAddItemToMenu
	| menu |
	menu := MenuMorph new.
	self deny: menu hasItems.
	(MBAddBaselineCommand target: (MBAbstractVersionInfo version: self) for: self  ) addItemToMenu: menu.
	self assert: menu hasItems.
! !

TestCase subclass: #MBPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Morphic-Tests'!

!MBPlatformTest methodsFor: 'as yet unclassified' stamp: 'AlexandreBergel 3/27/2011 11:24'!
getAllWindows
	^ World submorphs select: #isSystemWindow! !

!MBPlatformTest methodsFor: 'as yet unclassified' stamp: 'TesterBob 3/28/2011 15:46'!
testfindChangesForrelativeToRepository
	| windows |
	windows := self getAllWindows.
	MBPlatform current 
			findChangesFor: (MCPackage named: 'Compiler') workingCopy 
			relativeToRepository: MCDictionaryRepository new.
	(self getAllWindows copyWithoutAll: windows) do: #delete  ! !

!MBConfigurationInfoTest methodsFor: '*versionner-morphic-tests' stamp: 'dkh 3/6/2011 21:00'!
testConfigurationListMorphicMenu
	| menu |
	menu := MenuMorph new.
	self deny: menu hasItems.
	info listMenu: menu requestor: browser  .
	self assert: menu hasItems.
! !
